defmodule ChronoscopeWeb.API.V1.NTS.KeyEstablishmentController do
  use ChronoscopeWeb, :controller

  require Logger

  alias Chronoscope.NTS

  @default_port "4460"

  def get(conn, params) do
    host = to_charlist(params["host"])
    port = String.to_integer(params["port"] || @default_port)

    case NTS.key_establishment(host, port) do
      {:ok, configuration} ->
        json(conn, %{status: :ok, configuration: format_configuration(configuration)})

      {:error, error} ->
        json(conn, %{status: :error, reason: to_string(error)})
    end
  end

  defp format_configuration(configuration) do
    configuration
    |> Map.take([:aead_algorithms, :cookie_length, :cookies, :next_protocols, :port, :server])
    |> Map.update(:cookies, 0, &length/1)
  end
end
